@@ -32,8 +32,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -46,20 +46,19 @@ import aws_cdk.aws_sns
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class AddHeader(
-    metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.AddHeader"
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-ses-actions.AddHeader",
 ):
-    """Adds a header to the received email.
+    """(experimental) Adds a header to the received email.
 
-    stability
     :stability: experimental
     """
 
-    def __init__(self, *, name: str, value: str) -> None:
+    def __init__(self, *, name: builtins.str, value: builtins.str) -> None:
         """
-        :param name: The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
-        :param value: The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\r" or "\n").
+        :param name: (experimental) The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
+        :param value: (experimental) The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\r" or "\n").
 
-        stability
         :stability: experimental
         """
         props = AddHeaderProps(name=name, value=value)
@@ -68,13 +67,13 @@ class AddHeader(
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, _rule: aws_cdk.aws_ses.IReceiptRule
+        self,
+        _rule: aws_cdk.aws_ses.IReceiptRule,
     ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
-        """Returns the receipt rule action specification.
+        """(experimental) (experimental) Returns the receipt rule action specification.
 
         :param _rule: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_rule])
@@ -86,49 +85,50 @@ class AddHeader(
     name_mapping={"name": "name", "value": "value"},
 )
 class AddHeaderProps:
-    def __init__(self, *, name: str, value: str) -> None:
-        """Construction properties for a add header action.
+    def __init__(self, *, name: builtins.str, value: builtins.str) -> None:
+        """(experimental) Construction properties for a add header action.
 
-        :param name: The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
-        :param value: The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\r" or "\n").
+        :param name: (experimental) The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
+        :param value: (experimental) The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\r" or "\n").
 
-        stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "name": name,
             "value": value,
         }
 
     @builtins.property
-    def name(self) -> str:
-        """The name of the header to add.
+    def name(self) -> builtins.str:
+        """(experimental) The name of the header to add.
 
         Must be between 1 and 50 characters,
         inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters
         and dashes only.
 
-        stability
         :stability: experimental
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return result
 
     @builtins.property
-    def value(self) -> str:
-        """The value of the header to add.
+    def value(self) -> builtins.str:
+        """(experimental) The value of the header to add.
 
         Must be less than 2048 characters,
         and must not contain newline characters ("\r" or "\n").
 
-        stability
         :stability: experimental
         """
-        return self._values.get("value")
+        result = self._values.get("value")
+        assert result is not None, "Required property 'value' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -139,25 +139,23 @@ class AddHeaderProps:
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class Bounce(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Bounce"):
-    """Rejects the received email by returning a bounce response to the sender and, optionally, publishes a notification to Amazon SNS.
+    """(experimental) Rejects the received email by returning a bounce response to the sender and, optionally, publishes a notification to Amazon SNS.
 
-    stability
     :stability: experimental
     """
 
     def __init__(
         self,
         *,
-        sender: str,
+        sender: builtins.str,
         template: "BounceTemplate",
         topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
     ) -> None:
         """
-        :param sender: The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
-        :param template: The template containing the message, reply code and status code.
-        :param topic: The SNS topic to notify when the bounce action is taken. Default: no notification
+        :param sender: (experimental) The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
+        :param template: (experimental) The template containing the message, reply code and status code.
+        :param topic: (experimental) The SNS topic to notify when the bounce action is taken. Default: no notification
 
-        stability
         :stability: experimental
         """
         props = BounceProps(sender=sender, template=template, topic=topic)
@@ -166,13 +164,13 @@ class Bounce(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Bounce
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, _rule: aws_cdk.aws_ses.IReceiptRule
+        self,
+        _rule: aws_cdk.aws_ses.IReceiptRule,
     ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
-        """Returns the receipt rule action specification.
+        """(experimental) (experimental) Returns the receipt rule action specification.
 
         :param _rule: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_rule])
@@ -187,20 +185,19 @@ class BounceProps:
     def __init__(
         self,
         *,
-        sender: str,
+        sender: builtins.str,
         template: "BounceTemplate",
         topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
     ) -> None:
-        """Construction properties for a bounce action.
+        """(experimental) Construction properties for a bounce action.
 
-        :param sender: The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
-        :param template: The template containing the message, reply code and status code.
-        :param topic: The SNS topic to notify when the bounce action is taken. Default: no notification
+        :param sender: (experimental) The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
+        :param template: (experimental) The template containing the message, reply code and status code.
+        :param topic: (experimental) The SNS topic to notify when the bounce action is taken. Default: no notification
 
-        stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "sender": sender,
             "template": template,
         }
@@ -208,42 +205,43 @@ class BounceProps:
             self._values["topic"] = topic
 
     @builtins.property
-    def sender(self) -> str:
-        """The email address of the sender of the bounced email.
+    def sender(self) -> builtins.str:
+        """(experimental) The email address of the sender of the bounced email.
 
         This is the address
         from which the bounce message will be sent.
 
-        stability
         :stability: experimental
         """
-        return self._values.get("sender")
+        result = self._values.get("sender")
+        assert result is not None, "Required property 'sender' is missing"
+        return result
 
     @builtins.property
     def template(self) -> "BounceTemplate":
-        """The template containing the message, reply code and status code.
+        """(experimental) The template containing the message, reply code and status code.
 
-        stability
         :stability: experimental
         """
-        return self._values.get("template")
+        result = self._values.get("template")
+        assert result is not None, "Required property 'template' is missing"
+        return result
 
     @builtins.property
     def topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
-        """The SNS topic to notify when the bounce action is taken.
+        """(experimental) The SNS topic to notify when the bounce action is taken.
 
-        default
         :default: no notification
 
-        stability
         :stability: experimental
         """
-        return self._values.get("topic")
+        result = self._values.get("topic")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -253,27 +251,26 @@ class BounceProps:
 
 
 class BounceTemplate(
-    metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.BounceTemplate"
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-ses-actions.BounceTemplate",
 ):
-    """A bounce template.
+    """(experimental) A bounce template.
 
-    stability
     :stability: experimental
     """
 
     def __init__(
         self,
         *,
-        message: str,
-        smtp_reply_code: str,
-        status_code: typing.Optional[str] = None,
+        message: builtins.str,
+        smtp_reply_code: builtins.str,
+        status_code: typing.Optional[builtins.str] = None,
     ) -> None:
         """
-        :param message: Human-readable text to include in the bounce message.
-        :param smtp_reply_code: The SMTP reply code, as defined by RFC 5321.
-        :param status_code: The SMTP enhanced status code, as defined by RFC 3463.
+        :param message: (experimental) Human-readable text to include in the bounce message.
+        :param smtp_reply_code: (experimental) The SMTP reply code, as defined by RFC 5321.
+        :param status_code: (experimental) The SMTP enhanced status code, as defined by RFC 3463.
 
-        stability
         :stability: experimental
         """
         props = BounceTemplateProps(
@@ -282,56 +279,50 @@ class BounceTemplate(
 
         jsii.create(BounceTemplate, self, [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="MAILBOX_DOES_NOT_EXIST")
     def MAILBOX_DOES_NOT_EXIST(cls) -> "BounceTemplate":
         """
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "MAILBOX_DOES_NOT_EXIST")
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="MAILBOX_FULL")
     def MAILBOX_FULL(cls) -> "BounceTemplate":
         """
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "MAILBOX_FULL")
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="MESSAGE_CONTENT_REJECTED")
     def MESSAGE_CONTENT_REJECTED(cls) -> "BounceTemplate":
         """
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "MESSAGE_CONTENT_REJECTED")
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="MESSAGE_TOO_LARGE")
     def MESSAGE_TOO_LARGE(cls) -> "BounceTemplate":
         """
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "MESSAGE_TOO_LARGE")
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="TEMPORARY_FAILURE")
     def TEMPORARY_FAILURE(cls) -> "BounceTemplate":
         """
-        stability
         :stability: experimental
         """
         return jsii.sget(cls, "TEMPORARY_FAILURE")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="props")
     def props(self) -> "BounceTemplateProps":
         """
-        stability
         :stability: experimental
         """
         return jsii.get(self, "props")
@@ -350,20 +341,19 @@ class BounceTemplateProps:
     def __init__(
         self,
         *,
-        message: str,
-        smtp_reply_code: str,
-        status_code: typing.Optional[str] = None,
+        message: builtins.str,
+        smtp_reply_code: builtins.str,
+        status_code: typing.Optional[builtins.str] = None,
     ) -> None:
-        """Construction properties for a BounceTemplate.
+        """(experimental) Construction properties for a BounceTemplate.
 
-        :param message: Human-readable text to include in the bounce message.
-        :param smtp_reply_code: The SMTP reply code, as defined by RFC 5321.
-        :param status_code: The SMTP enhanced status code, as defined by RFC 3463.
+        :param message: (experimental) Human-readable text to include in the bounce message.
+        :param smtp_reply_code: (experimental) The SMTP reply code, as defined by RFC 5321.
+        :param status_code: (experimental) The SMTP enhanced status code, as defined by RFC 3463.
 
-        stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "message": message,
             "smtp_reply_code": smtp_reply_code,
         }
@@ -371,40 +361,40 @@ class BounceTemplateProps:
             self._values["status_code"] = status_code
 
     @builtins.property
-    def message(self) -> str:
-        """Human-readable text to include in the bounce message.
+    def message(self) -> builtins.str:
+        """(experimental) Human-readable text to include in the bounce message.
 
-        stability
         :stability: experimental
         """
-        return self._values.get("message")
+        result = self._values.get("message")
+        assert result is not None, "Required property 'message' is missing"
+        return result
 
     @builtins.property
-    def smtp_reply_code(self) -> str:
-        """The SMTP reply code, as defined by RFC 5321.
+    def smtp_reply_code(self) -> builtins.str:
+        """(experimental) The SMTP reply code, as defined by RFC 5321.
 
-        see
         :see: https://tools.ietf.org/html/rfc5321
-        stability
         :stability: experimental
         """
-        return self._values.get("smtp_reply_code")
+        result = self._values.get("smtp_reply_code")
+        assert result is not None, "Required property 'smtp_reply_code' is missing"
+        return result
 
     @builtins.property
-    def status_code(self) -> typing.Optional[str]:
-        """The SMTP enhanced status code, as defined by RFC 3463.
+    def status_code(self) -> typing.Optional[builtins.str]:
+        """(experimental) The SMTP enhanced status code, as defined by RFC 3463.
 
-        see
         :see: https://tools.ietf.org/html/rfc3463
-        stability
         :stability: experimental
         """
-        return self._values.get("status_code")
+        result = self._values.get("status_code")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -415,31 +405,27 @@ class BounceTemplateProps:
 
 @jsii.enum(jsii_type="@aws-cdk/aws-ses-actions.EmailEncoding")
 class EmailEncoding(enum.Enum):
-    """The type of email encoding to use for a SNS action.
+    """(experimental) The type of email encoding to use for a SNS action.
 
-    stability
     :stability: experimental
     """
 
     BASE64 = "BASE64"
-    """Base 64.
+    """(experimental) Base 64.
 
-    stability
     :stability: experimental
     """
     UTF8 = "UTF8"
-    """UTF-8.
+    """(experimental) UTF-8.
 
-    stability
     :stability: experimental
     """
 
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class Lambda(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Lambda"):
-    """Calls an AWS Lambda function, and optionally, publishes a notification to Amazon SNS.
+    """(experimental) Calls an AWS Lambda function, and optionally, publishes a notification to Amazon SNS.
 
-    stability
     :stability: experimental
     """
 
@@ -451,11 +437,10 @@ class Lambda(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Lambda
         topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
     ) -> None:
         """
-        :param function: The Lambda function to invoke.
-        :param invocation_type: The invocation type of the Lambda function. Default: Event
-        :param topic: The SNS topic to notify when the Lambda action is taken. Default: no notification
+        :param function: (experimental) The Lambda function to invoke.
+        :param invocation_type: (experimental) The invocation type of the Lambda function. Default: Event
+        :param topic: (experimental) The SNS topic to notify when the Lambda action is taken. Default: no notification
 
-        stability
         :stability: experimental
         """
         props = LambdaProps(
@@ -466,13 +451,13 @@ class Lambda(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Lambda
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, rule: aws_cdk.aws_ses.IReceiptRule
+        self,
+        rule: aws_cdk.aws_ses.IReceiptRule,
     ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
-        """Returns the receipt rule action specification.
+        """(experimental) (experimental) Returns the receipt rule action specification.
 
         :param rule: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [rule])
@@ -480,26 +465,23 @@ class Lambda(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Lambda
 
 @jsii.enum(jsii_type="@aws-cdk/aws-ses-actions.LambdaInvocationType")
 class LambdaInvocationType(enum.Enum):
-    """The type of invocation to use for a Lambda Action.
+    """(experimental) The type of invocation to use for a Lambda Action.
 
-    stability
     :stability: experimental
     """
 
     EVENT = "EVENT"
-    """The function will be invoked asynchronously.
+    """(experimental) The function will be invoked asynchronously.
 
-    stability
     :stability: experimental
     """
     REQUEST_RESPONSE = "REQUEST_RESPONSE"
-    """The function will be invoked sychronously.
+    """(experimental) The function will be invoked sychronously.
 
     Use RequestResponse only when
     you want to make a mail flow decision, such as whether to stop the receipt
     rule or the receipt rule set.
 
-    stability
     :stability: experimental
     """
 
@@ -518,19 +500,18 @@ class LambdaProps:
         self,
         *,
         function: aws_cdk.aws_lambda.IFunction,
-        invocation_type: typing.Optional["LambdaInvocationType"] = None,
+        invocation_type: typing.Optional[LambdaInvocationType] = None,
         topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
     ) -> None:
-        """Construction properties for a Lambda action.
+        """(experimental) Construction properties for a Lambda action.
 
-        :param function: The Lambda function to invoke.
-        :param invocation_type: The invocation type of the Lambda function. Default: Event
-        :param topic: The SNS topic to notify when the Lambda action is taken. Default: no notification
+        :param function: (experimental) The Lambda function to invoke.
+        :param invocation_type: (experimental) The invocation type of the Lambda function. Default: Event
+        :param topic: (experimental) The SNS topic to notify when the Lambda action is taken. Default: no notification
 
-        stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "function": function,
         }
         if invocation_type is not None:
@@ -540,41 +521,40 @@ class LambdaProps:
 
     @builtins.property
     def function(self) -> aws_cdk.aws_lambda.IFunction:
-        """The Lambda function to invoke.
+        """(experimental) The Lambda function to invoke.
 
-        stability
         :stability: experimental
         """
-        return self._values.get("function")
+        result = self._values.get("function")
+        assert result is not None, "Required property 'function' is missing"
+        return result
 
     @builtins.property
-    def invocation_type(self) -> typing.Optional["LambdaInvocationType"]:
-        """The invocation type of the Lambda function.
+    def invocation_type(self) -> typing.Optional[LambdaInvocationType]:
+        """(experimental) The invocation type of the Lambda function.
 
-        default
         :default: Event
 
-        stability
         :stability: experimental
         """
-        return self._values.get("invocation_type")
+        result = self._values.get("invocation_type")
+        return result
 
     @builtins.property
     def topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
-        """The SNS topic to notify when the Lambda action is taken.
+        """(experimental) The SNS topic to notify when the Lambda action is taken.
 
-        default
         :default: no notification
 
-        stability
         :stability: experimental
         """
-        return self._values.get("topic")
+        result = self._values.get("topic")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -585,9 +565,8 @@ class LambdaProps:
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class S3(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.S3"):
-    """Saves the received message to an Amazon S3 bucket and, optionally, publishes a notification to Amazon SNS.
+    """(experimental) Saves the received message to an Amazon S3 bucket and, optionally, publishes a notification to Amazon SNS.
 
-    stability
     :stability: experimental
     """
 
@@ -596,16 +575,15 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.S3"):
         *,
         bucket: aws_cdk.aws_s3.IBucket,
         kms_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
-        object_key_prefix: typing.Optional[str] = None,
+        object_key_prefix: typing.Optional[builtins.str] = None,
         topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
     ) -> None:
         """
-        :param bucket: The S3 bucket that incoming email will be saved to.
-        :param kms_key: The master key that SES should use to encrypt your emails before saving them to the S3 bucket. Default: no encryption
-        :param object_key_prefix: The key prefix of the S3 bucket. Default: no prefix
-        :param topic: The SNS topic to notify when the S3 action is taken. Default: no notification
+        :param bucket: (experimental) The S3 bucket that incoming email will be saved to.
+        :param kms_key: (experimental) The master key that SES should use to encrypt your emails before saving them to the S3 bucket. Default: no encryption
+        :param object_key_prefix: (experimental) The key prefix of the S3 bucket. Default: no prefix
+        :param topic: (experimental) The SNS topic to notify when the S3 action is taken. Default: no notification
 
-        stability
         :stability: experimental
         """
         props = S3Props(
@@ -619,13 +597,13 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.S3"):
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, rule: aws_cdk.aws_ses.IReceiptRule
+        self,
+        rule: aws_cdk.aws_ses.IReceiptRule,
     ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
-        """Returns the receipt rule action specification.
+        """(experimental) (experimental) Returns the receipt rule action specification.
 
         :param rule: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [rule])
@@ -647,20 +625,19 @@ class S3Props:
         *,
         bucket: aws_cdk.aws_s3.IBucket,
         kms_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
-        object_key_prefix: typing.Optional[str] = None,
+        object_key_prefix: typing.Optional[builtins.str] = None,
         topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
     ) -> None:
-        """Construction properties for a S3 action.
+        """(experimental) Construction properties for a S3 action.
 
-        :param bucket: The S3 bucket that incoming email will be saved to.
-        :param kms_key: The master key that SES should use to encrypt your emails before saving them to the S3 bucket. Default: no encryption
-        :param object_key_prefix: The key prefix of the S3 bucket. Default: no prefix
-        :param topic: The SNS topic to notify when the S3 action is taken. Default: no notification
+        :param bucket: (experimental) The S3 bucket that incoming email will be saved to.
+        :param kms_key: (experimental) The master key that SES should use to encrypt your emails before saving them to the S3 bucket. Default: no encryption
+        :param object_key_prefix: (experimental) The key prefix of the S3 bucket. Default: no prefix
+        :param topic: (experimental) The SNS topic to notify when the S3 action is taken. Default: no notification
 
-        stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "bucket": bucket,
         }
         if kms_key is not None:
@@ -672,53 +649,51 @@ class S3Props:
 
     @builtins.property
     def bucket(self) -> aws_cdk.aws_s3.IBucket:
-        """The S3 bucket that incoming email will be saved to.
+        """(experimental) The S3 bucket that incoming email will be saved to.
 
-        stability
         :stability: experimental
         """
-        return self._values.get("bucket")
+        result = self._values.get("bucket")
+        assert result is not None, "Required property 'bucket' is missing"
+        return result
 
     @builtins.property
     def kms_key(self) -> typing.Optional[aws_cdk.aws_kms.IKey]:
-        """The master key that SES should use to encrypt your emails before saving them to the S3 bucket.
+        """(experimental) The master key that SES should use to encrypt your emails before saving them to the S3 bucket.
 
-        default
         :default: no encryption
 
-        stability
         :stability: experimental
         """
-        return self._values.get("kms_key")
+        result = self._values.get("kms_key")
+        return result
 
     @builtins.property
-    def object_key_prefix(self) -> typing.Optional[str]:
-        """The key prefix of the S3 bucket.
+    def object_key_prefix(self) -> typing.Optional[builtins.str]:
+        """(experimental) The key prefix of the S3 bucket.
 
-        default
         :default: no prefix
 
-        stability
         :stability: experimental
         """
-        return self._values.get("object_key_prefix")
+        result = self._values.get("object_key_prefix")
+        return result
 
     @builtins.property
     def topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
-        """The SNS topic to notify when the S3 action is taken.
+        """(experimental) The SNS topic to notify when the S3 action is taken.
 
-        default
         :default: no notification
 
-        stability
         :stability: experimental
         """
-        return self._values.get("topic")
+        result = self._values.get("topic")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -729,9 +704,8 @@ class S3Props:
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class Sns(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Sns"):
-    """Publishes the email content within a notification to Amazon SNS.
+    """(experimental) Publishes the email content within a notification to Amazon SNS.
 
-    stability
     :stability: experimental
     """
 
@@ -739,13 +713,12 @@ class Sns(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Sns"):
         self,
         *,
         topic: aws_cdk.aws_sns.ITopic,
-        encoding: typing.Optional["EmailEncoding"] = None,
+        encoding: typing.Optional[EmailEncoding] = None,
     ) -> None:
         """
-        :param topic: The SNS topic to notify.
-        :param encoding: The encoding to use for the email within the Amazon SNS notification. Default: UTF-8
+        :param topic: (experimental) The SNS topic to notify.
+        :param encoding: (experimental) The encoding to use for the email within the Amazon SNS notification. Default: UTF-8
 
-        stability
         :stability: experimental
         """
         props = SnsProps(topic=topic, encoding=encoding)
@@ -754,13 +727,13 @@ class Sns(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Sns"):
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, _rule: aws_cdk.aws_ses.IReceiptRule
+        self,
+        _rule: aws_cdk.aws_ses.IReceiptRule,
     ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
-        """Returns the receipt rule action specification.
+        """(experimental) (experimental) Returns the receipt rule action specification.
 
         :param _rule: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_rule])
@@ -776,17 +749,16 @@ class SnsProps:
         self,
         *,
         topic: aws_cdk.aws_sns.ITopic,
-        encoding: typing.Optional["EmailEncoding"] = None,
+        encoding: typing.Optional[EmailEncoding] = None,
     ) -> None:
-        """Construction properties for a SNS action.
+        """(experimental) Construction properties for a SNS action.
 
-        :param topic: The SNS topic to notify.
-        :param encoding: The encoding to use for the email within the Amazon SNS notification. Default: UTF-8
+        :param topic: (experimental) The SNS topic to notify.
+        :param encoding: (experimental) The encoding to use for the email within the Amazon SNS notification. Default: UTF-8
 
-        stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "topic": topic,
         }
         if encoding is not None:
@@ -794,29 +766,29 @@ class SnsProps:
 
     @builtins.property
     def topic(self) -> aws_cdk.aws_sns.ITopic:
-        """The SNS topic to notify.
+        """(experimental) The SNS topic to notify.
 
-        stability
         :stability: experimental
         """
-        return self._values.get("topic")
+        result = self._values.get("topic")
+        assert result is not None, "Required property 'topic' is missing"
+        return result
 
     @builtins.property
-    def encoding(self) -> typing.Optional["EmailEncoding"]:
-        """The encoding to use for the email within the Amazon SNS notification.
+    def encoding(self) -> typing.Optional[EmailEncoding]:
+        """(experimental) The encoding to use for the email within the Amazon SNS notification.
 
-        default
         :default: UTF-8
 
-        stability
         :stability: experimental
         """
-        return self._values.get("encoding")
+        result = self._values.get("encoding")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -827,19 +799,19 @@ class SnsProps:
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class Stop(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Stop"):
-    """Terminates the evaluation of the receipt rule set and optionally publishes a notification to Amazon SNS.
+    """(experimental) Terminates the evaluation of the receipt rule set and optionally publishes a notification to Amazon SNS.
 
-    stability
     :stability: experimental
     """
 
     def __init__(
-        self, *, topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None
+        self,
+        *,
+        topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
     ) -> None:
         """
-        :param topic: The SNS topic to notify when the stop action is taken.
+        :param topic: (experimental) The SNS topic to notify when the stop action is taken.
 
-        stability
         :stability: experimental
         """
         props = StopProps(topic=topic)
@@ -848,13 +820,13 @@ class Stop(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Stop"):
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, _rule: aws_cdk.aws_ses.IReceiptRule
+        self,
+        _rule: aws_cdk.aws_ses.IReceiptRule,
     ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
-        """Returns the receipt rule action specification.
+        """(experimental) (experimental) Returns the receipt rule action specification.
 
         :param _rule: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "bind", [_rule])
@@ -867,32 +839,33 @@ class Stop(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Stop"):
 )
 class StopProps:
     def __init__(
-        self, *, topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None
+        self,
+        *,
+        topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
     ) -> None:
-        """Construction properties for a stop action.
+        """(experimental) Construction properties for a stop action.
 
-        :param topic: The SNS topic to notify when the stop action is taken.
+        :param topic: (experimental) The SNS topic to notify when the stop action is taken.
 
-        stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if topic is not None:
             self._values["topic"] = topic
 
     @builtins.property
     def topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
-        """The SNS topic to notify when the stop action is taken.
+        """(experimental) The SNS topic to notify when the stop action is taken.
 
-        stability
         :stability: experimental
         """
-        return self._values.get("topic")
+        result = self._values.get("topic")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
