@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_kms._jsii
@@ -19,9 +19,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-ses-actions",
-    "1.60.0",
+    "1.70.0",
     __name__[0:-6],
-    "aws-ses-actions@1.60.0.jsii.tgz",
+    "aws-ses-actions@1.70.0.jsii.tgz",
 )
 
 __all__ = [
